@@ -117,6 +117,9 @@ class CallGraphGenerator:
 
         items = list(self.downloads_dir.iterdir())
         if len(items) != 1:
+            for file in items:
+                if (file.startswith(self.product) | file.startswith(self.product.replace("-", "_"))):
+                    return file
             self._format_error(err_phase,\
                 'Expecting a single downloaded item {}'.format(str(items)))
             raise CallGraphGeneratorError()
@@ -171,8 +174,8 @@ class CallGraphGenerator:
                 nfiles = len(list(d.glob('**/*.py')))
                 if nfiles == 0:
                     shutil.rmtree(d.as_posix())
-
-        items = list(self.untar_dir.iterdir())
+        items_temp = list(self.untar_dir.iterdir())
+        items = [val for val in items_temp if ((not str(val).endswith(".data")) & (not str(val).endswith(".pth")) & (not str(val).endswith("/tests"))& (not str(val).endswith("/docs")))]
         if len(items) != 1:
             # return the item with the same name as the product
             prod_replaced = ''
@@ -284,7 +287,7 @@ class CallGraphGenerator:
                 cg = json.load(f)
             except Exception:
                 self._format_error('producer',\
-                    'Call graph path does is not JSON formatted {}. Contents {}'.format(cg_path.as_posix(), f.read()))
+                    'Call graph is not JSON formatted {}. Contents {}'.format(cg_path.as_posix(), f.read()))
                 raise CallGraphGeneratorError()
 
         # PyCG must produce a call graph with the key "depset"
@@ -366,4 +369,4 @@ class CallGraphGenerator:
             path.mkdir(parents=True)
 
 class CallGraphGeneratorError(Exception):
-    pass
\ No newline at end of file
+    pass
